"""
Placeholder test so that pytest won't complain about not being able to find anything.
"""


def test_placeholder():
    """
    Placeholder to allow pytest to succeed before real tests are in place.
    (If there are no tests, it will exit with code 5.)
    """
